Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java

Issue 10913231: Issue 76: In Debugger Expressions view crashes on numeric property name (Closed) Base URL: https://chromedevtools.googlecode.com/svn/trunk
Patch Set: todo Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | plugins/org.chromium.sdk/src/org/chromium/sdk/JsVariable.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java
diff --git a/plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java b/plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java
index 0e1cd1dff19988ab899e155e9d78a9b69d764102..8635dc1129a1e26ff2a91dcf0ae73deb5c6fcd34 100755
--- a/plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java
+++ b/plugins/org.chromium.debug.core/src/org/chromium/debug/core/model/StackFrame.java
@@ -220,23 +220,22 @@ public class StackFrame extends StackFrameBase implements IDropToFrame {
public int compare(Variable var1, Variable var2) {
return compareNameObjects(getNameObject(var1), getNameObject(var2));
}
// Get property name as String or Integer.
private Object getNameObject(Variable var) {
String name = var.getName();
int len = name.length();
if (len >= 3 && name.charAt(0) == '[' && name.charAt(len-1) == ']') {
- Integer i = Integer.valueOf(name.substring(1, len - 1));
- return i;
+ return Long.valueOf(name.substring(1, len - 1));
apavlov 2012/09/13 03:27:09 What about number-like properties of arbitrary Lon
Peter Rybin 2012/09/19 16:04:34 These numbers are originally from Long from JSON p
}
return name;
}
// Compare property name (either string or integer).
private int compareNameObjects(Object nameObj1, Object nameObj2) {
- if (nameObj1 instanceof Integer) {
- Integer i1 = (Integer) nameObj1;
- if (nameObj2 instanceof Integer) {
- Integer i2 = (Integer) nameObj2;
- return i1.compareTo(i2);
+ if (nameObj1 instanceof Long) {
+ Long n1 = (Long) nameObj1;
+ if (nameObj2 instanceof Long) {
+ Long n2 = (Long) nameObj2;
+ return n1.compareTo(n2);
} else {
return COMPARE_INT_WITH_STRING;
}
@@ -220,23 +220,22 @@ public class StackFrame extends StackFrameBase implements IDropToFrame {
return compareNameObjects(getNameObject(var1), getNameObject(var2));
}
- // Get property name as String or Integer.
+ // Get property name as String or Long.
private Object getNameObject(Variable var) {
String name = var.getName();
@@ -220,23 +220,22 @@ public class StackFrame extends StackFrameBase implements IDropToFrame {
return name;
}
- // Compare property name (either string or integer).
+ // Compare property name (either string or long).
private int compareNameObjects(Object nameObj1, Object nameObj2) {
« no previous file with comments | « no previous file | plugins/org.chromium.sdk/src/org/chromium/sdk/JsVariable.java » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698